---
jupyter:
  kernelspec:
    display_name: Python 3
    language: python
    name: python3
---

```{python}
# This is an unfrozen cell. Works as usual.
print("I'm a regular cell so I run and print!")
```

```{python deletable=FALSE, editable=FALSE, run_control={'frozen': True}, eval=FALSE}
# This is an frozen cell
print("I'm frozen so Im not executed :(")
```
